@@ -10,7 +10,7 @@ class Network(object):
 	def __init__(self):
 
 		# variables.
-		self.info = None
+		self._info_ = None
 		self.api_key = None
 
 		#
